@@ -25,16 +25,12 @@ class QuoteChecker(object):
         # When user wants only single quotes
         '\'': {
             'good_single': '\'',
-            'good_multiline': '\'\'\'',
             'bad_single': '"',
-            'bad_multiline': '"""',
         },
         # When user wants only double quotes
         '"': {
             'good_single': '"',
-            'good_multiline': '"""',
             'bad_single': '\'',
-            'bad_multiline': '\'\'\'',
         },
     }
     # Provide aliases for Windows CLI support
@@ -95,25 +91,32 @@ class QuoteChecker(object):
         cls._register_opt(parser, '--multiline-quotes', default=None, action='store',
                           parse_from_config=True, type='choice',
                           choices=sorted(cls.MULTILINE_QUOTES.keys()),
-                          help='Quote to expect in all files (default: \')')
+                          help='Quote to expect in all files (default: """)')
 
     @classmethod
     def parse_options(cls, options):
+        # Define our default config
+        # cls.config = {good_single: ', good_multiline: ''', bad_single: ", bad_multiline: """}
+        cls.config = {}
+        cls.config.update(cls.INLINE_QUOTES['\''])
+        cls.config.update(cls.MULTILINE_QUOTES['"""'])
+
         # If `options.quotes` was specified, then use it
         if hasattr(options, 'quotes') and options.quotes is not None:
             # https://docs.python.org/2/library/warnings.html#warnings.warn
             warnings.warn('flake8-quotes has deprecated `quotes` in favor of `inline-quotes`. '
                           'Please update your configuration')
-            cls.config = cls.INLINE_QUOTES[options.quotes].copy()
+            cls.config.update(cls.INLINE_QUOTES[options.quotes])
         # Otherwise, use the supported `inline_quotes`
         else:
-            # cls.config = {good_single: ', good_multiline: ''', bad_single: ", bad_multiline: """}
-            cls.config = cls.INLINE_QUOTES[options.inline_quotes].copy()
+            # cls.config = {good_single: ', good_multiline: """, bad_single: ", bad_multiline: '''}
+            #   -> {good_single: ", good_multiline: """, bad_single: ', bad_multiline: '''}
+            cls.config.update(cls.INLINE_QUOTES[options.inline_quotes])
 
         # If multiline quotes was specified, overload our config with those options
         if hasattr(options, 'multiline_quotes') and options.multiline_quotes is not None:
-            # cls.config = {good_single: ', good_multiline: ''', bad_single: ", bad_multiline: """}
-            #   -> {good_single: ', good_multiline: """, bad_single: ", bad_multiline: '''}
+            # cls.config = {good_single: ', good_multiline: """, bad_single: ", bad_multiline: '''}
+            #   -> {good_single: ', good_multiline: ''', bad_single: ", bad_multiline: """}
             cls.config.update(cls.MULTILINE_QUOTES[options.multiline_quotes])
 
     def get_file_contents(self):
@@ -156,45 +159,47 @@ class QuoteChecker(object):
             first_quote_index = token.string.index(last_quote_char)
             unprefixed_string = token.string[first_quote_index:]
 
-            # If our string has a valid multiline start, then ignore it
-            #   (""")foo""" -> good (continue)
-            #   (''')foo' -> possibly bad
-            #   (")foo" -> possibly bad
-            #   (')foo' -> possibly bad
-            if unprefixed_string.startswith(self.config['good_multiline']):
-                continue
+            # Determine if our string is multiline-based
+            #   "foo"[0] * 3 = " * 3 = """
+            #   "foo"[0:3] = "fo
+            #   """foo"""[0:3] = """
+            is_multiline_string = unprefixed_string[0] * 3 == unprefixed_string[0:3]
+            start_row, start_col = token.start
 
-            # If our string isn't a known bad multiline
-            #   (''')foo''' -> bad (see reporting at end)
-            #   (')foo' -> possibly bad
-            #   (")foo" -> possibly bad
-            if not unprefixed_string.startswith(self.config['bad_multiline']):
-                # If our string is a known good string, then ignore it
-                #   (')foo' -> good (continue)
-                #   (")foo" -> possibly bad
-                if unprefixed_string.startswith(self.config['good_single']):
+            # If our string is multiline
+            if is_multiline_string:
+                # If our string is or containing a known good string, then ignore it
+                #   (""")foo""" -> good (continue)
+                #   '''foo(""")''' -> good (continue)
+                #   (''')foo''' -> possibly bad
+                if self.config['good_multiline'] in unprefixed_string:
                     continue
 
-                # If our string is wrapping a known good string, then ignore it
+                # Output our error
+                yield {
+                    'message': 'Q001 Remove bad quotes from multiline string.',
+                    'line': start_row,
+                    'col': start_col,
+                }
+            # Otherwise (string is inline quote)
+            else:
+                # If our string is a known good string, then ignore it
+                #   (')foo' -> good (continue)
                 #   "it(')s" -> good (continue)
-                #   "foo" -> possibly bad
+                #   (")foo" -> possibly bad
                 if self.config['good_single'] in unprefixed_string:
                     continue
 
-                # Otherwise, report it
-                #   (")foo" -> bad (see reporting at end)
-
-            # Report our error
-            start_row, start_col = token.start
-            yield {
-                'message': 'Q000 Remove bad quotes.',
-                'line': start_row,
-                'col': start_col,
-            }
+                # Output our error
+                yield {
+                    'message': 'Q000 Remove bad quotes.',
+                    'line': start_row,
+                    'col': start_col,
+                }
 
 
 class Token:
-    '''Python 2 and 3 compatible token'''
+    """Python 2 and 3 compatible token"""
     def __init__(self, token):
         self.token = token
 
